@@ -79,15 +79,15 @@ StepInformation <- function (char, ambiguousTokens = c('-', '?')) {
   Lk
 }
 
-#' Number of trees with _m_ additional steps
+#' Number of trees with _m_ steps
 #' 
-#' Calculate the number of trees with _m_ extra steps under Fitch parsimony
-#' where _a_ leaves are labelled with one state, and _b_ leaves labelled with
-#' a second state.
+#' Calculate the number of trees in which Fitch parsimony will reconstruct
+#' _m_ steps, where _a_ leaves are labelled with one state, and _b_ leaves are
+#' labelled with a second state.
 #' 
 #' Implementation of theorem 1 from \insertCite{Carter1990;textual}{TreeTools}
 #' 
-#' @param m Number of steps
+#' @param m Number of steps.
 #' @param a,b Number of leaves labelled `0` and `1`.
 #' 
 #' @references 
@@ -101,6 +101,18 @@ StepInformation <- function (char, ambiguousTokens = c('-', '?')) {
 #' 
 #' (\insertRef{Steel1996}{TreeSearch})
 #' @importFrom TreeTools LogDoubleFactorial
+#' @examples 
+#' # The character `0 0 0 1 1 1`
+#' Carter1(1, 3, 3) # Exactly one step
+#' Carter1(2, 3, 3) # Two steps (one extra step)
+#' 
+#' # Number of trees that the character can map onto with exactly _m_ steps
+#' # if non-parsimonious reconstructions are permitted:
+#' cumsum(sapply(1:3, Carter1, 3, 3))
+#' 
+#' # Three steps allow the character to map onto any of the 105 six-leaf trees.
+#' 
+#' @template MRS
 #' @family profile parsimony functions
 #' @export
 Carter1 <- function (m, a, b) {
@@ -108,7 +120,9 @@ Carter1 <- function (m, a, b) {
   twoN <- n + n
   twoM <- m + m
   N <- function (n, m) {
-    if (n < m) 0 else {
+    if (n < m) {
+      0
+    } else {
       nMinusM <- n - m
       factorial(n + nMinusM - 1L) / prod(
         factorial(nMinusM),
@@ -227,6 +241,7 @@ LogCarter1 <- function (m, a, b) {
 #' @examples
 #' WithOneExtraStep(1, 2, 3)
 #' @importFrom TreeTools NUnrootedMult DoubleFactorial
+#' @family profile parsimony functions
 #' @export
 WithOneExtraStep <- function (...) {
   splits <- c(...)
